@@ -2,8 +2,6 @@
 
 Based off spec: https://github.com/Society-for-Internet-Blaseball-Research/blaseball-api-spec
 """
-import requests
-import requests_cache
 from blaseball_mike.session import session, check_network_response
 
 
@@ -12,7 +10,7 @@ BASE_GITHUB = 'https://raw.githubusercontent.com/xSke/blaseball-site-files/main/
 
 
 def get_global_events():
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/globalEvents')
     return check_network_response(res)
 
@@ -21,7 +19,7 @@ def get_all_teams():
     """
     Returns dictionary keyed by team ID
     """
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/allTeams')
     return {t['id']: t for t in check_network_response(res)}
 
@@ -30,31 +28,31 @@ def get_all_divisions():
     """
     Returns dictionary keyed by division ID
     """
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/allDivisions')
     return {d['id']: d for d in check_network_response(res)}
 
 
 def get_league(id_='d8545021-e9fc-48a3-af74-48685950a183'):
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/league?id={id_}')
     return check_network_response(res)
 
 
 def get_subleague(id_):
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/subleague?id={id_}')
     return check_network_response(res)
 
 
 def get_division(id_):
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/division?id={id_}')
     return check_network_response(res)
 
 
 def get_team(id_):
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/team?id={id_}')
     return check_network_response(res)
 
@@ -68,7 +66,7 @@ def get_player(id_):
         return {}
     if isinstance(id_, list):
         id_ = ','.join(id_)
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/players?ids={id_}')
     return {p['id']: p for p in check_network_response(res)}
 
@@ -78,7 +76,7 @@ def get_games(season, day):
     Season and day will be 1 indexed.
     Returns as dictionary with game ID as key.
     """
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/games?season={season - 1}&day={day - 1}')
     return {g['id']: g for g in check_network_response(res)}
 
@@ -88,19 +86,19 @@ def get_tournament(tournament, day):
     Day will be 1 indexed. Tournament is 0 indexed.
     Returns as dictionary with game ID as key.
     """
-    s = requests_cache.CachedSession(backend="memory", expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/games?tournament={tournament}&day={day - 1}')
     return {g['id']: g for g in check_network_response(res)}
 
 
 def get_game_by_id(id_):
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/gameById/{id_}')
     return check_network_response(res)
 
 
 def get_offseason_election_details():
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/offseasonSetup')
     return check_network_response(res)
 
@@ -109,7 +107,7 @@ def get_offseason_recap(season):
     """
     Season will be 1 indexed.
     """
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/offseasonRecap?season={season - 1}')
     return check_network_response(res)
 
@@ -120,7 +118,7 @@ def get_offseason_bonus_results(id_):
     """
     if isinstance(id_, list):
         id_ = ','.join(id_)
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/bonusResults?ids={id_}')
     return {g['id']: g for g in check_network_response(res)}
 
@@ -131,7 +129,7 @@ def get_offseason_decree_results(id_):
     """
     if isinstance(id_, list):
         id_ = ','.join(id_)
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/decreeResults?ids={id_}')
     return {g['id']: g for g in check_network_response(res)}
 
@@ -139,7 +137,7 @@ def get_offseason_decree_results(id_):
 def get_offseason_event_results(id_):
     if isinstance(id_, list):
         id_ = ','.join(id_)
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/eventResults?ids={id_}')
     return {g['id']: g for g in check_network_response(res)}
 
@@ -148,13 +146,13 @@ def get_playoff_details(season):
     """
     Season will be 1 indexed.
     """
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/playoffs?number={season - 1}')
     return check_network_response(res)
 
 
 def get_playoff_round(id_):
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/playoffRound?id={id_}')
     return check_network_response(res)
 
@@ -165,13 +163,13 @@ def get_playoff_matchups(id_):
     """
     if isinstance(id_, list):
         id_ = ','.join(id_)
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/playoffMatchups?ids={id_}')
     return {g['id']: g for g in check_network_response(res)}
 
 
 def get_standings(id_):
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/standings?id={id_}')
     return check_network_response(res)
 
@@ -180,13 +178,13 @@ def get_season(season_number):
     """
     Season number is 1 indexed
     """
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/season?number={season_number - 1}')
     return check_network_response(res)
 
 
 def get_tiebreakers(id):
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/tiebreakers?id={id}')
     return {g['id']: g for g in check_network_response(res)}
 
@@ -194,7 +192,7 @@ def get_tiebreakers(id):
 def get_game_statsheets(ids):
     if isinstance(ids, list):
         ids = ','.join(ids)
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/gameStatsheets?ids={ids}')
     return {s['id']: s for s in check_network_response(res)}
 
@@ -202,7 +200,7 @@ def get_game_statsheets(ids):
 def get_player_statsheets(ids):
     if isinstance(ids, list):
         ids = ','.join(ids)
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/playerSeasonStats?ids={ids}')
     return {s['id']: s for s in check_network_response(res)}
 
@@ -210,7 +208,7 @@ def get_player_statsheets(ids):
 def get_season_statsheets(ids):
     if isinstance(ids, list):
         ids = ','.join(ids)
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/seasonStatsheets?ids={ids}')
     return {s['id']: s for s in check_network_response(res)}
 
@@ -218,25 +216,25 @@ def get_season_statsheets(ids):
 def get_team_statsheets(ids):
     if isinstance(ids, list):
         ids = ','.join(ids)
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/teamSeasonStats?ids={ids}')
     return {s['id']: s for s in check_network_response(res)}
 
 
 def get_idols():
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get('https://www.blaseball.com/api/getIdols')
     return check_network_response(res)
 
 
 def get_tributes():
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get('https://www.blaseball.com/api/getTribute')
     return check_network_response(res)
 
 
 def get_simulation_data():
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/simulationData')
     return check_network_response(res)
 
@@ -244,7 +242,7 @@ def get_simulation_data():
 def get_attributes(ids):
     if isinstance(ids, list):
         ids = ','.join(ids)
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/mods?ids={ids}')
     return check_network_response(res)
 
@@ -252,13 +250,13 @@ def get_attributes(ids):
 def get_items(ids):
     if isinstance(ids, list):
         ids = ','.join(ids)
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/items?ids={ids}')
     return check_network_response(res)
 
 
 def get_weather():
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_GITHUB}/weather.json')
     return check_network_response(res)
 
@@ -266,7 +264,7 @@ def get_weather():
 def get_blood(ids):
     if isinstance(ids, list):
         ids = ','.join(ids)
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/blood?ids={ids}')
     return check_network_response(res)
 
@@ -274,6 +272,6 @@ def get_blood(ids):
 def get_coffee(ids):
     if isinstance(ids, list):
         ids = ','.join(ids)
-    s = requests_cache.CachedSession(backend="memory",expire_after=5)
+    s = session(5)
     res = s.get(f'{BASE_URL}/coffee?ids={ids}')
     return check_network_response(res)
